DeviceIdLogger class

Lightweight logger for device_id_manager

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

d(String message) → void
Debug log
e(String message) → void
Error log
i(String message) → void
Info log
setEnabled(bool enabled) → void
Enable or disable logging
w(String message) → void
Warning log